@@ -11,22 +11,27 @@ VersionInfo = NamedTuple(
     "VersionInfo", major=int, minor=int, micro=int, releaselevel=str, serial=int
 )
 
-version_info = VersionInfo(major=0, minor=1, micro=4, releaselevel="", serial=0)
+version_info = VersionInfo(major=0, minor=2, micro=1, releaselevel="", serial=0)
 
 __title__ = "baguette"
 __author__ = "takos22"
-__version__ = "0.1.4"
+__version__ = "0.2.1"
 
 __all__ = [
     "Baguette",
     "Headers",
     "make_headers",
+    "render",
     "Response",
     "HTMLResponse",
     "PlainTextResponse",
     "JSONResponse",
     "EmptyResponse",
+    "RedirectResponse",
+    "FileResponse",
     "make_response",
+    "make_error_response",
+    "redirect",
     "Request",
     "View",
 ]
@@ -34,13 +39,18 @@ __all__ = [
 from . import testing
 from .app import Baguette
 from .headers import Headers, make_headers
+from .rendering import render
 from .request import Request
 from .responses import (
     EmptyResponse,
+    FileResponse,
     HTMLResponse,
     JSONResponse,
     PlainTextResponse,
+    RedirectResponse,
     Response,
+    make_error_response,
     make_response,
+    redirect,
 )
 from .view import View
