@@ -3,6 +3,7 @@ import ssl
 import traceback
 import typing
 
+from . import rendering
 from .headers import Headers, make_headers
 from .httpexceptions import BadRequest, HTTPException, InternalServerError
 from .request import Request
@@ -34,6 +35,18 @@ class Baguette:
             Default headers to include in every request.
             Default: No headers.
 
+        static_url_path: :class:`str`
+            URL path for the static file handler.
+            Default: ``"static"``.
+
+        static_directory: :class:`str`
+            Path to the folder containing static files.
+            Default: ``"static"``.
+
+        templates_directory: :class:`str`
+            Path to the folder containing the HTML templates.
+            Default: ``"templates"``.
+
         error_response_type: :class:`str`
             Type of response to use in case of error.
             One of: ``"plain"``, ``"json"``, ``"html"``.
@@ -57,6 +70,15 @@ class Baguette:
         default_headers: :class:`Headers`
             Default headers included in every response.
 
+        static_url_path: :class:`str`
+            URL path for the static file handler.
+
+        static_directory: :class:`str`
+            Path to the folder containing static files.
+
+        renderer: :class:`~baguette.rendering.Renderer`
+            Class that renders the templates.
+
         error_response_type: :class:`str`
             Type of response to use in case of error.
             One of: ``"plain"``, ``"json"``, ``"html"``
@@ -74,6 +96,7 @@ class Baguette:
         default_headers: HeadersType = None,
         static_url_path: str = "static",
         static_directory: str = "static",
+        templates_directory: str = "static",
         error_response_type: str = "plain",
         error_include_description: bool = True,
     ):
@@ -84,6 +107,8 @@ class Baguette:
         self.static_url_path = static_url_path
         self.static_directory = static_directory
 
+        self.renderer = rendering.init(templates_directory)
+
         self.add_route(
             path=f"{self.static_url_path}/<filename:path>",
             handler=self.handle_static_file,
@@ -300,7 +325,7 @@ class Baguette:
         name: str = None,
         defaults: dict = None,
     ):
-        """Adds the handler function to the router with the given path.
+        """Decorator to add a handler function to the router with the given path.
 
         Parameters
         ----------
