@@ -8,7 +8,7 @@ import aiofiles
 
 from .headers import Headers, make_headers
 from .httpexceptions import HTTPException, NotFound
-from .types import Result
+from .types import HeadersType, Result
 from .utils import safe_join
 
 HTML_TAG_REGEX = re.compile(r"<\s*\w+[^>]*>.*?<\s*/\s*\w+\s*>")
@@ -21,7 +21,7 @@ class Response:
         self,
         body: typing.Union[str, bytes],
         status_code: int = 200,
-        headers: typing.Union[dict, Headers] = None,
+        headers: typing.Optional[HeadersType] = None,
     ):
         if isinstance(body, str):
             self.text: str = body
@@ -56,13 +56,12 @@ class JSONResponse(Response):
         self,
         data: typing.Any,
         status_code: int = 200,
-        headers: typing.Union[dict, Headers] = None,
+        headers: typing.Optional[HeadersType] = None,
     ):
         self.json = data
         body: str = json.dumps(data)
-        headers = make_headers(headers)
-        headers["content-type"] = "application/json"
         super().__init__(body, status_code, headers)
+        self.headers["content-type"] = "application/json"
 
 
 class PlainTextResponse(Response):
@@ -70,11 +69,10 @@ class PlainTextResponse(Response):
         self,
         text: typing.Union[str, bytes],
         status_code: int = 200,
-        headers: typing.Union[dict, Headers] = None,
+        headers: typing.Optional[HeadersType] = None,
     ):
-        headers = make_headers(headers)
-        headers["content-type"] = "text/plain; charset=" + self.CHARSET
         super().__init__(text, status_code, headers)
+        self.headers["content-type"] = "text/plain; charset=" + self.CHARSET
 
 
 class HTMLResponse(Response):
@@ -82,22 +80,32 @@ class HTMLResponse(Response):
         self,
         html: typing.Union[str, bytes],
         status_code: int = 200,
-        headers: typing.Union[dict, Headers] = None,
+        headers: typing.Optional[HeadersType] = None,
     ):
-        headers = make_headers(headers)
-        headers["content-type"] = "text/html; charset=" + self.CHARSET
         super().__init__(html, status_code, headers)
+        self.headers["content-type"] = "text/html; charset=" + self.CHARSET
 
 
 class EmptyResponse(PlainTextResponse):
     def __init__(
         self,
         status_code: int = 204,
-        headers: typing.Union[dict, Headers] = None,
+        headers: typing.Optional[HeadersType] = None,
     ):
         super().__init__("", status_code, headers)
 
 
+class RedirectResponse(Response):
+    def __init__(
+        self,
+        location: str,
+        status_code: int = 301,
+        headers: typing.Optional[HeadersType] = None,
+    ):
+        super().__init__("", status_code, headers)
+        self.headers["location"] = location
+
+
 class FileResponse(Response):
     def __init__(
         self,
@@ -107,7 +115,7 @@ class FileResponse(Response):
         as_attachment: bool = False,
         add_etags: bool = True,
         status_code: int = 200,
-        headers: typing.Union[dict, Headers] = None,
+        headers: typing.Optional[HeadersType] = None,
     ):
         self.mimetype = mimetype
         self.attachment_filename = attachment_filename
@@ -181,30 +189,35 @@ def make_response(result: Result) -> Response:
     if issubclass(type(result), Response):
         return result
 
+    body = result
+    status_code_or_headers = None
+    status_code = None
+    headers = None
+
     if isinstance(result, tuple):
         body, status_code_or_headers, headers = result + (None,) * (
             3 - len(result)
         )
-    else:
-        body = result
-        status_code_or_headers = None
-        status_code = None
-        headers = None
 
-    if status_code_or_headers is None:
-        status_code = None
-    elif isinstance(status_code_or_headers, int):
+    if isinstance(status_code_or_headers, int):
         status_code = status_code_or_headers
     elif isinstance(status_code_or_headers, (list, dict, Headers)):
         headers = status_code_or_headers
-        status_code = None
 
     headers = make_headers(headers)
 
+    if not isinstance(body, (list, dict, str, bytes)) and body is not None:
+        body = str(body)
+
     if isinstance(body, (list, dict)):
         response = JSONResponse(body, status_code or 200, headers)
-    elif isinstance(body, str):
-        if HTML_TAG_REGEX.search(body) is not None:
+    elif isinstance(body, (str, bytes)):
+        if (
+            HTML_TAG_REGEX.search(
+                body.decode() if isinstance(body, bytes) else body
+            )
+            is not None
+        ):
             response = HTMLResponse(body, status_code or 200, headers)
         else:
             response = PlainTextResponse(body, status_code or 200, headers)
@@ -216,8 +229,6 @@ def make_response(result: Result) -> Response:
         #         " but instead an empty string and a 204 status code or an EmptyResponse() instance"  # noqa: E501
         #     )
         # )
-    else:
-        response = PlainTextResponse(str(body), status_code or 200, headers)
 
     return response
 
@@ -289,3 +300,32 @@ def make_error_response(
         raise ValueError(
             "Bad response type. Must be one of: 'plain', 'json', 'html'"
         )
+
+
+def redirect(
+    location: str,
+    status_code: int = 301,
+    headers: typing.Optional[HeadersType] = None,
+) -> RedirectResponse:
+    """Redirect the request to location.
+
+    Arguments
+    ---------
+        location: :class:`str`
+            The location to redirect the request to.
+
+        status_code: :class:`int`
+            Status code of the redirect response.
+            Default: ``301``.
+
+        headers: anything accepted by :func:`make_headers`
+            Headers to include in the response.
+            Any location header will be overwritten with the location parameter.
+            Default: ``None``.
+
+    Returns
+    -------
+        :class:`RedirectResponse`
+            The created redirect response.
+    """
+    return RedirectResponse(location, status_code, headers)
