@@ -1,6 +1,7 @@
+import os
 import typing
 
-if typing.TYPE_CHECKING:  # pragma: no cover
+if typing.TYPE_CHECKING:
     from .headers import Headers
     from .request import Request
     from .responses import Response
@@ -37,3 +38,5 @@ ParamsType = typing.Union[
 ]
 BodyType = typing.Union[str, typing.Iterable[str], typing.AsyncIterator[str]]
 JSONType = typing.Union[dict, list, tuple, str, int, float, bool]
+
+FilePath = typing.Union[bytes, str, os.PathLike]
